API docs for “spamfighter.interfaces.IDomainBindable”

# Class s.i.IDomainBindable(Interface):

Part of spamfighter.interfaces View Source View In Hierarchy

Интерфейс объекта, который при помещении в домен должен узнавать о том, что он там оказался.

После попадания в домен у объекта будет вызван метод bind.

Method | bind | Извещение объекту о том, что он был помещен в домен.

def bind(domain, name): (source)
Извещение объекту о том, что он был помещен в домен.

Parameters | domain | домен (type: `IDomain` )
| name | имя в домене (type: `str` )